/********************
	DISPLAY Object() 
********************/

/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Extension Catalog Code.
 *
 * The Initial Developer of the Original Code is
 * Shahin Saneinejad.
 *
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function Display() {
	this.catMenuList = document.getElementById("catMenuList");
	this.tree = document.getElementById("exTree");
	this.nameCol = document.getElementById("name");
	this.descCol = document.getElementById("desc");
	this.verCol = document.getElementById("version");
	this.treeChildren = null;
	this.searchBox = document.getElementById("searchBox");
}

Display.prototype.changeCategory = function() {
	this.searchBox.value = "Search";
	for (category = 0; category < 6; category++) {
		for (i = 0; i < extensions[category].length; i++) {
			extensions[category][i].showThisOne();
		}
	}
	this.refreshTree();
}

Display.prototype.refreshTree = function() {
	this.clearTree();
	this.fillTree(this.catMenuList.selectedIndex);
	/* 
	0	all
	1 Internet
	2 UI
	3 Developer Tools
	4 Utilities
	5 Other
	*/
}

Display.prototype.clearTree = function() {
	 try {
		 this.tree.removeChild(this.treeChildren);
	 }
	 catch (e) {
	 }
}

Display.prototype.fillTree = function(category) {
	if (category != 0)
		category--;
	
	var ti, tr, tc = null;
	this.treeChildren = document.createElement("treechildren");
	this.tree.appendChild(this.treeChildren);
	
	var displayedCount = 0;
	for (i = 0; i < extensions[category].length; i++) {
		if (extensions[category][i].show) {
			ti = document.createElement("treeitem");
		
			// add name to Name column
			tc = document.createElement("treecell");
			tc.setAttribute("label", extensions[category][i].name);
			tr = document.createElement("treerow");
			tr.setAttribute("id", "row"+displayedCount);
			tr.setAttribute("arrayIndex", i);
			tr.appendChild(tc);
			
			tc = document.createElement("treecell");
			tc.setAttribute("label", extensions[category][i].shortdesc);
			tr.appendChild(tc);
		
			tc = document.createElement("treecell");
			tc.setAttribute("label", extensions[category][i].version);
			tr.appendChild(tc);
			
			ti.appendChild(tr);
			
			this.treeChildren.appendChild(ti);
			displayedCount++;
		}
	}

	document.getElementById("myDeck").selectedIndex=1;
	
	// clumsy way to make sure a catMenuList element is selected on startup, so that showDetails() works
	if (category == 0)
		this.catMenuList.selectedIndex = 0;
	
	this.tree.view.selection.select(0);
	this.showDetails();
}

Display.prototype.showDetails = function() {
	var treeIndex = myDisplay.tree.currentIndex;
	var selected = document.getElementById("row"+treeIndex);
	var arrayIndex = selected.getAttribute("arrayIndex");
	
	var category = myDisplay.catMenuList.selectedIndex;
	
	if (category != 0)
		category--;
	
	var ext = extensions[category][arrayIndex];
	
	var versionCaption = document.getElementById("versionCaption");
	var homepageCaption = document.getElementById("homepageCaption");
	var boxCaption = document.getElementById("boxCaption");
	var descAreaIFrame = document.getElementById("descAreaIFrame");
	
	versionCaption.setAttribute("value", ext.version);
	homepageCaption.setAttribute("onclick", "window.open('" + ext.homepage + "');");
	boxCaption.setAttribute("label",("Extension Details: " + ext.name));

	ext.desc = ext.desc + "<style type='text/css'>body { font-family: helvetica, arial, sans-serif; font-size:11px; background-color:#ECE9D8; }</style>";
	
	var iframeBody = descAreaIFrame.contentDocument;
	iframeBody.body.innerHTML = ext.desc;	
}
