/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Extension Catalog Code.
 *
 * The Initial Developer of the Original Code is
 * Shahin Saneinejad.
 *
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any ones of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const extensionList = "http://database.mozdev.org/extensions.xml";
const extensionDescriptions = "http://database.mozdev.org/extensiondescriptions.xml";
const extensionCategories = "http://database.mozdev.org/extensioncategories.xml";

const APP = navigator.vendor;
const VER = navigator.vendorSub;
const OS = getOS();

function getOS() {
	if (navigator.platform == "Win32")
		return "Windows";
	else if (navigator.platform.toLowerCase() == "linux")
		return "Linux";
	else
		return "Mac";
}
 
//NodeLists of all extensions and their descriptions
var extList, extDesc = null;		

// 2-dimensional array of categories and category member extensions
var extensions = new Array();
extensions[0] = new Array();	// all extensions
extensions[1] = new Array();  // internet extensions
extensions[2] = new Array();  // UI extensions
extensions[3] = new Array();  // developer tools extensions
extensions[4] = new Array();  // utilities extensions
extensions[5] = new Array();  // other extensions

var myDisplay;

function init() {
	myDisplay = new Display();
	getExtensions();
	setTimeout('populateExtensionArrays()', 1);
	setTimeout('myDisplay.fillTree(0)', 1000);	
}

function getExtensions() {
	var request = new XMLHttpRequest();
	
	// get extensions
	request.open("GET", extensionList, false);
	request.send(null);
	extList = request.responseXML;
	
	// get extension descriptions
	request = new XMLHttpRequest();
	request.open("GET", extensionDescriptions, false);
	
	try {	request.send(null);	}
	catch (e) {	alert("Error: "+e.message);	}	
	
	extDesc = request.responseXML;
	
	document.getElementById("meter").setAttribute("value",40);
	document.getElementById("meterdesc").setAttribute("value","Retreiving extension lists...");
}

function populateExtensionArrays() {	
	for (category=0; category<6; category++) {
		var pathExpression = "//extension  [version/compatible[ @app='"+APP+"' and (@fromver<='"+VER+"' or not(@fromver)) and (@tover>='"+VER+"' or not(@tover)) ]]  [version[@os='"+OS+"' or not(@os)]] " + getSubCategories(category);
		try {
			var nodeSnapshot = extList.evaluate(pathExpression, extList, null, 7, null);
		}
		catch (e) {
			alert("Error: "+e.message);
		}
		
		for (index=0; index<nodeSnapshot.snapshotLength; index++) {
			try {
				var verTag = extList.evaluate("//version [parent::extension[@id='"+nodeSnapshot.snapshotItem(index).getAttribute("id")+"']] [compatible[ @app='"+APP+"' and (@fromver<='"+VER+"' or not(@fromver)) and (@tover>='"+VER+"' or not(@tover)) ]]  [@os='"+OS+"' or not(@os)]",extList,null,7,null).snapshotItem(0);
				extensions[category][index] = new Extension(nodeSnapshot.snapshotItem(index),verTag);
			}
			catch (e) {
				alert("Error: "+e.message);
			}
		}
	}
	
	document.getElementById("meter").setAttribute("value",95);
	document.getElementById("meterdesc").setAttribute("value","Loading interface...");
}

function getSubCategories(category) {
		switch (category) {
			case 0:
				return "";
				break
			case 1:
				return "[@categories='blog' or @categories='chat' or @categories='news']";
				break
			case 2:
				return "[@categories='search' or @categories='nav' or @categories='pagedisplay' or @categories='tabs' or @categories='mousegest']";
				break
			case 3:
				return "[@categories='dev']";
				break
			case 4:
				return "[@categories='privacy' or @categories='kiosk' or @categories='config' or @categories='download']";
				break
			case 5:
				return "[not(@categories)]";
				break;
		}
}

function handleSearch() {
	var searchString = myDisplay.searchBox.value;
	var category = myDisplay.catMenuList.selectedIndex;
	
	if (category != 0)
		category--;
		
	for (i = 0; i < extensions[category].length; i++) {
		if ( compare(searchString, extensions[category][i].desc) == false ) {
			extensions[category][i].dontShowThisOne();
		}
		else
			extensions[category][i].showThisOne();
	}
	
	myDisplay.refreshTree();
	
}

function compare(checkString, checkAgainst) {
	checkString = checkString.toLowerCase();
	checkAgainst = checkAgainst.toLowerCase();
	var stringArray = checkString.split(" ");
	
	for (j = 0; j < stringArray.length; j++) {
		if (checkAgainst.indexOf(stringArray[j]) != -1)
			continue;
		else
			break;
	}
	
	if ((j == stringArray.length) || (stringArray[0] == "")) {
		return true;
	}
	
	return false;
}

function installExtension() {
	var selected = myDisplay.tree.currentIndex;
	var category = myDisplay.catMenuList.selectedIndex;
	if (category != 0)
		category--;
	
	var uri = extensions[category][selected].installURI;
	
	if (InstallTrigger.updateEnabled()) {
		InstallTrigger.startSoftwareUpdate(uri);
	}
}
